Superdesk-server is written and maintained by Sourcefabric and
various contributors:

#### The Superdesk team

- [Petr Jašek](mailto:petr.jasek@sourcefabric.org)
- Adrian Magdas
- Anca Farcas
- Ioan Pocol
- Mugur Rus
- Peter Lamut
- Yauhen Kirylau

#### Contributions

- Andrew Marwood
- Francesco Occhipinti
- Gabriel Nistor
- Kuna Siva
- Mayur Dhamanwala
- Tolga Akin
